tokenizer\_tools.evaluator.token package
========================================

Submodules
----------

tokenizer\_tools.evaluator.token.base\_evaluator module
-------------------------------------------------------

.. automodule:: tokenizer_tools.evaluator.token.base_evaluator
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.evaluator.token.tag\_level module
--------------------------------------------------

.. automodule:: tokenizer_tools.evaluator.token.tag_level
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.evaluator.token.token\_level module
----------------------------------------------------

.. automodule:: tokenizer_tools.evaluator.token.token_level
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.evaluator.token
   :members:
   :undoc-members:
   :show-inheritance:
